@@ -187,7 +187,7 @@ class GRPOLearner:
         # Use 8-bit optimizer if configured
         if self.config.training.use_8bit_optimizer and BNB_AVAILABLE:
             hud_console.info("Using 8-bit AdamW optimizer from bitsandbytes")
-            optimizer = bnb.optim.AdamW8bit(
+            optimizer = bnb.optim.AdamW8bit(  # type: ignore
                 trainable_params,
                 lr=self.config.training.lr,
                 betas=self.config.training.adam_betas,
@@ -561,15 +561,15 @@ def sanity_check(
     old_logp: torch.Tensor | None,
     ref_logp: torch.Tensor | None,
 ) -> None:
-    assert "assistant_mask" in sample.inputs  # noqa: S101
+    assert "assistant_mask" in sample.inputs
     m = sample.inputs["assistant_mask"]
     if old_logp is None or ref_logp is None:
         return
     with torch.no_grad():
         B, K = pol_logp.shape
-        assert old_logp.shape == (B, K), "old_logp shape mismatch"  # noqa: S101
-        assert ref_logp.shape == (B, K), "ref_logp shape mismatch"  # noqa: S101
-        assert m.shape == (B, K), "assistant_mask shape mismatch"  # noqa: S101
+        assert old_logp.shape == (B, K), "old_logp shape mismatch"
+        assert ref_logp.shape == (B, K), "ref_logp shape mismatch"
+        assert m.shape == (B, K), "assistant_mask shape mismatch"
 
         # Check mask is subset of attention_mask[:, 1:]
         att = sample.inputs.get("attention_mask", None)
